# Image Archive

The image archive holds all my photographs.

## Overview

The archive consists of a single Git repository, where the images are managed using [Git-Annex](https://git-annex.branchable.com/). The local repository is synchronized to a remote repository on my server. The setup allows for having multiple other clients, who have their own local repo and synchronize it via the remote. On the server there are several (2 at the time) other repositories (on different HDDs) that get the data from the main repo and thereby, acts as backup. Clients can have their own (offline) backup, which is another repository on an HDD.

Access permissions to the remote repository are managed using [Gitolite](https://gitolite.com/).

## Initial Setup

### Server Main Repo

#### Install Gitolite

These steps are all done on the server

- Create gitolite user `git`
- Switch to `git` user: `sudo su git`
- Copy host's SSH public key to `/home/git/<HOST_SSH_KEY>.pub`
  - This is the key of the host who manages the repository
- Ensure `~/bin` exists and is in the path
- Clone [Gitolite's Source](https://github.com/sitaramc/gitolite) to `<GITOLITE_PATH>`
- Install it by running `<GITOLITE_PATH>/install -ln`
  - Will create a symlink `~/bin/gitolite` to the gitolite executable
- Edit `~/.gitolite.rc` and add `'git-annex-shell ua'` to the `ENABLE` list
- Setup gitolite using `gitolite setup -pk ~/<HOST_SSH_KEY>.pub`

#### Update Gitolite

These steps are all done on the server

- Switch to `git` user: `sudo su git`
- Pull changes from Gitolite's upstream
- Re-run `gitolite setup -pk ~/<HOST_SSH_KEY>.pub`

### Initialize Git Repo

These steps are all done on the admin host

- Clone Gitolite's admin repo: `git clone git@<SERVER_ADDRESS>:gitolite-admin`
- Add new repo to `gitolite-admin/conf/gitolite.conf`:

```
repo archive
    RW+     =   jeanclaude
```

- Commit and push
  - This creates the repository `archive.git` in `~/repositories/`

### Move Repository to Different Disk

These steps are all done on the server.
The repository is initialized on the main disk. To move it elsewhere, do:

- Move repo to desired location: `mv ~/repositories/archive.git /mnt/images`
- Create symlink back to original location: `ln -s /mnt/images/archive.git ~/repositories/archive.git`

### Initialize Git-Annex

These steps are all done on the server

- From within the repo, initialize git-annex repo `origin`: `git-annex init origin`

### Configure Git-Annex

These steps are all done on the server

- Add to `server` group: `git annex group . server`
- Make main repo want all files:
  - `git annex want . "include=*"`
  - `git annex required . "include=*"`
- Specify number of copies: `git annex numcopies 3`

These steps are all done from a clone of the archive repo

- Include media types, but exclude [Rawtherapee](http://rawtherapee.com/) `.pp3` sidecard files: `git annex config --set annex.largefiles "(include=*.CR2 or include=*.cr2 or include=*.JPG or include=*.jpg or include=*.CR3 or include=*.cr3 or include=*.MOV or include=*.mov or include=*.MP4 or include=*.mp4 or include=*.AVI or include=*.avi) and exclude=*.pp3"`
- Prevent `git annex sync` from auto committing changes: `git annex config --set annex.autocommit false`

## Add New Client

These steps are all done on the admin host

- Navigate to Gitolite's admin repo
- Get client's public SSH key `<CLIENT_SSH_KEY>.pub`
- Place key in `gitolite-admin/keydir/<CLIENT_SSH_KEY>.pub`
- Add repository permissions for `<CLIENT>` to `gitolite-admin/conf/gitolite.conf`:

```
repo archive
    RW+     =   <CLIENT>
```

- Commit and push
- TODO: Do I need to create a Linux user account for the client?

## Setup Local Repository

These steps are all done on the client's host

> Only possible if the client has read permissions the repo

- Clone archive repo: `git clone git@<SERVER_ADDRESS>:archive Archive`
- From within the repo, initialize git-annex repo: `git-annex init <CLIEN_NAME>`
- Add to `client` group: `git annex group . client`
- Make main repo require/want all files which are: 1. not yet backup by the server and 2. not included in an offline backup (or hold by a client, who has to do the offline backup):
  - `present or (not (copies=backup:2) and (copies=client:0 or copies=offline:0)`
    - Do I need `present`?
  - `git annex want . <CONDITION>`
  - `git annex required . <CONDITION>`

## Server Backup Setup

These steps are all done on the server

### Prepare Backup Repo

- Prepare partition and mount to `<BACKUP_PATH>`
- Go to `<BACKUP_PATH>`
- Clone archive repo: `git clone /mnt/image/archive.git --bare`
- Got into repo `cd archive.git`
- From within the repo, initialize git-annex repo: `git-annex init <BACKUP_NAME>`
- Specify what to fetch from origin by inserting `fetch = +refs/heads/*:refs/remotes/origin/*` into tag `[remote "origin"]` of the git config `./config`
- Add to `backup` and `server` groups:
  - `git annex group . server`
  - `git annex group . backup`
- Make main repo want all files (including old versions):
  - `git annex want . anything`
    - TODO: Is this really required?
  - `git annex required . anything`
- Specify repo as trusted: `git annex trust here --force`
  - This can be done (as no-one has direct access and hence, nothing can get deleted) and is also needed (as clients do not have direct access and hence, are unable to lock a file when dropping)
- Get all data: `git annex sync --content`

### Configure Server Main Repo

- Go to main archive in `/mnt/images/archive.git`
- Add new remote for backup repo: `git remote add <BACKUP_NAME> <BACKUP_PATH>/archive.git`
- Optical: Add `git annex sync --content` to `hooks/post-receive`

## Local Backup Setup

These steps are all done on the host

- Prepare partition and mount to `<BACKUP_PATH>`
- Go to `<BACKUP_PATH>`
- Clone archive repo: `git clone <ARCHIVE_PATH>`
- From within the repo, initialize git-annex repo: `git-annex init <BACKUP_NAME>`
- Git annex init repo: `git annex init <some_name>`
- Add server repo as remote: `git remote add server git@<SERVER_ADDRESS>:archive`
- Add to `backup` and `offline` groups:
  - `git annex group . server`
  - `git annex group . backup`
- Make main repo want all files (including old versions):
  - `git annex want . anything`
    - TODO: Is this really required?
  - `git annex required . anything`
- Specify repo as trusted: `git annex trust here --force`
  - This can be done (as this repos wants `anything`, so nothing can get deleted) and is also needed (as clients do not have direct access and hence, are unable to lock a file when dropping)
- Get all data: `git annex sync --content`
