# Edge Router

## Setup SSH
- Generate SSH key on client
- Copy SSH key to router
- Assign key to user
```
configure
loadkey <user> <path_to_key>
commit
save
exit
```
- Remove key: `rm <path_to_key>`
- Check if login works by reconnecting
- Disable password-based login
```
configure
set service ssh disable-password-authentication
commit
save
exit
```

## Setup VPN

### Server Side
- Make sure date/time is correct: `show date`
- Login as root: `sudo su`
- Generate DH: `openssl dhparam -out /config/auth/dh.pem -2 2048`
- `cd /usr/lib/ssl/misc`
- Generate Root Certificate
    - Generate: `./CA.pl -newca`
        - Set `common name` to `root`
    - Copy certificates/key to right location:
        - `cp demoCA/cacert.pem /config/auth`
        - `cp demoCA/private/cakey.pem /config/auth`
- Generate Server Certificate
    - Generate: `./CA.pl -newreq`
        - Set `common name` to `server`
    - Sign: `./CA.pl -sign`
    - Move certificate/key to right location:
        - `mv newcert.pem /config/auth/server.pem`
        - `mv newkey.pem /config/auth/server.key`
    - Remove password from the key: `openssl rsa -in /config/auth/server.key -out /config/auth/server-no-pass.key`
    - Overwritten no-pass version: `mv /config/auth/server-no-pass.key /config/auth/server.key `
- Generate Client Certificate
    - Generate: `./CA.pl -newreq`
        - Set `common name` to some client name
    - Sign: `./CA.pl -sign`
    - Move certificate/key to right location:
        - `mv newcert.pem /config/auth/client.pem`
        - `mv newkey.pem /config/auth/client.key`
    - Remove password from the key (optional): `openssl rsa -in /config/auth/client.key -out /config/auth/client-no-pass.key`
    - Overwrite no-pass version: `mv /config/auth/client-no-pass.key /config/auth/client.key`
    - Add right permissions: `chmod 644 /config/auth/client.key`
- Verify content of `/config/auth`
    ```
    ls -l /config/auth
    -rw-r--r--    1 root     vyattacf      4477 Jan 21 13:02 cacert.pem
    -rw-------    1 root     vyattacf      1854 Jan 21 13:02 cakey.pem
    -rw-r--r--    1 root     vyattacf      1675 Jan 21 13:06 client1.key
    -rw-r--r--    1 root     root          4647 Jan 21 13:05 client1.pem
    -rw-r--r--    1 root     vyattacf      1675 Jan 21 13:24 client2.key
    -rw-r--r--    1 root     vyattacf      4647 Jan 21 13:24 client2.pem
    -rw-r--r--    1 root     vyattacf       424 Jan 21 12:44 dh.pem
    -rw-------    1 root     vyattacf      1679 Jan 21 13:06 server.key
    -rw-r--r--    1 root     root          4642 Jan 21 13:02 server.pem
    ```
- Restart OpenVPN Server: `systemctl restart openvpn`
- Exit sudo: `exit`
- Enter configure mode: `configure`
- Add firewall rule:
    ```
    set firewall name WAN_LOCAL rule 30 action accept
    set firewall name WAN_LOCAL rule 30 description openvpn
    set firewall name WAN_LOCAL rule 30 destination port 1194
    set firewall name WAN_LOCAL rule 30 protocol udp
    ```
    - Check that the new rule has higher priority than the drop rule (done in the interface)

- Configure virtual tunnel interface:
    ```
    set interfaces openvpn vtun0 mode server
    set interfaces openvpn vtun0 server subnet 172.16.1.0/24
    set interfaces openvpn vtun0 server push-route 192.168.1.0/24
    set interfaces openvpn vtun0 server name-server 192.168.1.1
    ```
- Link certificate/key to the virtual interface
    ```
    set interfaces openvpn vtun0 tls ca-cert-file /config/auth/cacert.pem
    set interfaces openvpn vtun0 tls cert-file /config/auth/server.pem
    set interfaces openvpn vtun0 tls key-file /config/auth/server.key
    set interfaces openvpn vtun0 tls dh-file /config/auth/dh.pem
    ```
- Add virtual tunnel interface to the DNS forwaring interface list (optional): `set service dns forwarding listen-on vtun0`
- Exit `commit ; save`


### Client Side
- Copy `cacert.pem`, `client.pem`, `client.key` to client
- Create `er.ovpn`
    ```
    client
    dev tun
    proto udp
    remote jeanclaudegraf.ch 1194
    float
    resolv-retry infinite 
    nobind
    persist-key 
    persist-tun 
    verb 3
    ca cacert.pem 
    cert client.pem
    key client.key
    ```
    - Append `redirect-gateway def1` to redirect all traffic through the VPN (optional)

### Configuration
- Edit `/usr/lib/ssl/misc/CA.pl` to extend duration of CA
- Edit `/usr/lib/ssl/openssl.cnf` to extend duration of certificates

### Renew Certificate
- Requires the regeneration as described above


Source: https://help.ui.com/hc/en-us/articles/115015971688-EdgeRouter-OpenVPN-Server

## Move DHCP Logs to dedicated Log
- Moves the log to `/var/log/user/dhcpd`

```
configure
set service dhcp-server global-parameters 'log-facility local2;'
commit
save
exit
```

```
configure
set system syslog file dhcpd facility local2 level debug
set system syslog file dhcpd archive files 5
set system syslog file dhcpd archive size 5000
commit
save
exit
```

## DHCP Server not working reliable
- Set administrative `set service dhcp-server shared-network-name <DHCP_Server_Name> authoritative enable`
