# Latex

- Remove TOC: `\renewcommand\contentsname{}`

- Todomark with compile warning: 

```
\usepackage{xcolor}
\newcommand{\todo}[1]{\textcolor{red}{TODO: #1}\PackageWarning{TODO:}{#1!}}

%\newcommand*{\PRINTTODO}{}

\newcommand{\todo}[1]{
    \textcolor{red}{TODO: #1}
    \ifdefined\PRINTTODO
        \PackageWarning{TODO:}{#1!}
    \fi
}

```

- Increase depth of listings
```
\usepackage{enumitem}
\setlistdepth{20}
\renewlist{itemize}{itemize}{20}

% initially, use dots for all levels
\setlist[itemize]{label=$\cdot$}

% customize the first 3 levels
\setlist[itemize,1]{label=\textbullet}
\setlist[itemize,2]{label=--}
\setlist[itemize,3]{label=*}
```

## Beamer
- Make only one item apear at time time globally: `\beamerdefaultoverlayspecification{<+->}`
- Make hidden items grayed out: `\setbeamercovered{transparent=50}`
- Infos about overlay specification: <https://tex.stackexchange.com/questions/154521/relative-overlay-specification-in-beamer/154527#154527>
- Start with empty itemize by adding `[<+(1)->]`
- Create image overlay over whole text
```
\visible<5->{
    \begin{tikzpicture}[remember picture,overlay]
        \node at (current page.center) {
            \includegraphics[height=0.8\textheight]{./Figures/LH-FullDesc.png}
        };
    \end{tikzpicture}
}
```
- Make all frames top aligned: `\documentclass[t]{beamer}`
- Create black slide:
```
\bgroup
\setbeamercolor{background canvas}{bg=black}
\setbeamertemplate{navigation symbols}{}
\begin{frame}[plain]{}
\end{frame}
\egroup
```

## Bibliography
- General overview: <https://tex.stackexchange.com/a/25702/166952>
- `natbib` vs `biblatex`: <https://tex.stackexchange.com/a/5105/166952>

### Biblatex
- Template for `biblatex`
```
\documentclass{<someclass>}

\usepackage[<language options>]{babel}% Recommended
\usepackage{csquotes}% Recommended

\usepackage[style=<somebiblatexstyle>,<other options>]{biblatex}

\addbibresource[<options for bib resources>]{<mybibfile>.bib}

\begin{document}

A bare citation command: \autocite{<key>}.

A citation command for use in the flow of text: As \textcite{<key>} said \dots

\printbibliography[<options for printing>]

\end{document}
```

- Bib Entry types are not standardized any differ depending on the used package
    - The most standardized ones are:
        - article: An article from a journal or magazine
            - Required: author, title, journal, year
            - Optional: volume, number, pages, month, note
        - book: A book with an explicit publisher
            - Required: author or editor, title, publisher, year
            - Optional: volume or number, series, address, edition, month, note
        - booklet: A work that is printed and bound, but without a named publisher or sponsoring institution
            - Required: title
            - Optional: author, howpublished, address, month, year, note
        - inbook: A part of a book, e.g., a chpater, section, or whatever and/or a range of pages
            - Required: author or editor, title, chapter and/or pages, publisher, year
            - Optional: volume or number, series, type, address, edition, month, note
        - incollection: A part of a book having its own title
            - Required: author, title, booktitle, publisher, year
            - Optional: editor, volume or number, series, type, chapter, pages, address, edition, month, note
        - inproceedings: An article in a conference proceedings
            - Required: author, title, booktitle, year
            - Optional: editor, volume or number, series, pages, address, month, organization, publisher, note
        - manual: Technical documentation
            - Required field: title
            - Optional: author, organization, address, edition, month, year, note
        - mastersthesis: A master's thesis
            - Required: author, title, school, year
            - Optional: type, address, month, note
        - misc: Use this type when nothing else fits. A warning will be issued if all optional fields are empty (i.e., the entire entry is empty or has only ignored fields)
            - Required: none
            - Optional: author, title, howpublished, month, year, note
        - phdthesis: A Ph.D. thesis
            - Required: author, title, school, year
            - Optional: type, address, month, note
        - proceedings: Conference proceedings
            - Required: title, year
            - Optional: editor, volume or number, series, address, publisher, note, month, organization
        - techreport: A report published by a school or other institution, usually numbered within a series
            - Required: author, title, institution, year
            - Optional: type, number, address, month, note
        - unpublished: A document having an author and title, but not formally published
            - Required: author, title, note
            - Optional: month, year
    - For more information: <http://bib-it.sourceforge.net/help/fieldsAndEntryTypes.php>

### Bibtex
- Add url:
```
@misc{bworld,
    author = {Ingo Lütkebohle},
    title = {{BWorld Robot Control Software}},
    howpublished = "\url{http://aiweb.techfak.uni-bielefeld.de/content/bworld-robot-control-software/}",
    year = {2008},
    note = "[Online; accessed 19-July-2008]"
}
```

### Biblatex
- Add url
@online{ford,
author = {Ford, Rebecca},
title  = {Earthquake: Twitter Users Learned of Tremors
          Seconds Before Feeling Them},
date   = {2011-08},
url    = {http://www.hollywoodreporter.com/news/earthquake-twitter-users-learned-tremors-226481}
}

## Important
- Always place labels after caption: <https://tex.stackexchange.com/questions/32325/why-does-an-environments-label-have-to-appear-after-the-caption>

## Spaces
- There are two kind of spaces:
    - Skips: Have a dynamic size
    - Keens: Have a fixed size
- Spaces can be ``normal'' (breaking) and non-breaking

|              | Skips | Kerns |
|              | ---   | ---   |
| Breaking     | ' '   |       |
| Non-Breaking | '~'   | '\,'  |


- Lstlisting breakts syntax hightliging when a dollar sign is used
    - Reset highlighting using `%stopzone` after `\end{lstlisting}`

## Arch Linux
- Find required package: `tlmgr info <LATEX_PACKAGE> | grep collection`
